# Stubs for zope.schema._compat (Python 3.6)
#
# NOTE: This dynamically typed stub was automatically generated by stubgen.

from typing import Any

PY3: Any
PY2: Any
string_types: Any
text_type = str
binary_type = bytes
integer_types: Any

def non_native_string(x: Any): ...
def make_binary(x: Any): ...
text_type = unicode
binary_type = str
